==> cmod-0.9.tar.gz: cmod-0.9/env.h <==
/* cmod - set up the user environment with module files.
   Copyright (C) 1997 by the authors of cmod (see AUTHORS).

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#ifndef ENV_H
#define ENV_H

#include <stdio.h>

/* An environment variable is stored in a "struct env" entry.  All
   codes that need access to the implementation of a "struct env"
   resides in env.c, where the internals of this struct is declared. */

struct env;


/* A collection of environment variables are collectively stored
   in a "struct envarray". */

struct envarray;


/*
 * "struct env" methods.
 */

/* Constructor.  The caller must allocate the memory.  This will turn
   the random bits at e into an env object.  The fragment separator
   will be set to ':'. */

extern void env_ctor(struct env *e);


/* Destructor.  Frees all memory that is allocated by the object, and
   turns into a pile of random bits.  The memory itself is not
   deallocated. */

extern void env_dtor(struct env *e);


/* Return true if FRAG is present as a SEP-separated fragment of E. */

extern int env_frag_present(struct env *e, char sep, const char *frag);


/* Append a fragment to the variable.  No duplicate check is done.  It
   is the responsibility of the caller to ensure that FRAG doesn't
   contain the fragment delimiter SEP.  Ownership of the memory
   pointed to by FRAG is passed to E. */

extern void env_append_one_frag(struct env *e, char sep, const char *frag);


/* Split the SEP-separated fragments in FRAGS and append each frag to
   E.  If UNIQUE is true each fragment will only be added if it isn't
   already present.  Ownership of the memory pointed to by FRAGS
   remains with the caller. */

extern void env_append_frags(struct env *e, char sep, const char *frags,
			     int unique);

/* Prepend a fragment to the variable.  No duplicate check is done.
   It is the responsibility of the caller to ensure that FRAG doesn't
   contain the fragment delimiter SEP.  Ownership of the memory
   pointed to by FRAG is passed to E. */

extern void env_prepend_one_frag(struct env *e, char sep, char *frag);


/* Split the SEP-separated fragments in FRAGS and prepend each frag to
   E.  If UNIQUE is true any fragment already present in E will be
   removed before the fragment is prepended.  Ownership of the memory
   pointed to by FRAGS remains with the caller.  The first framgent on
   FRAGS will be the first fragment on E after the operation. */

extern void env_prepend_frags(struct env *e, char sep, const char *frags,
			      int unique);


/* Remove all SEP-separated frags from E which are equal to FRAG. */

extern void env_remove_one_frag(struct env *e, char sep, const char *frag);


/* Split the SEP-separated fragments in FRAGS and remove all fragments
   that are equal to any of them from E. */

extern void env_remove_frags(struct env *e, char sep, const char *frags);


/* Set the variable to a non-fragmented string.  Any previous value
   is lost, and the variable becomes non-fragmented.  Ownership of VAL
   passes to E. */

extern void env_setenv(struct env *e, char *val);

/* Make E explicitly unset. */

extern void env_unsetenv(struct env *e);

/* Dump the value of E to F, readable for shell SH. */
extern void env_dump(struct env *e, FILE *f, const char *sh);


/* Iterate through all fragments.  The iterator can be used like this:

   int i;
   char *fragment;
   for (i = 0; (fragment = env_iterate(e, ':', &i)) != NULL; )
       printf("fragment: %s\n", fragment);

   The loop variable i is incremented each time env_iterate is called.
   env_iterate returns NULL when there are no more fragments to
   fetch. */

extern const char *env_iterate(struct env *e, char sep, int *iterator);


/* Return the value of the variable as a string.  The returned value
   is only valid until the next call to any method that may modify the
   variable.  Returns NULL if the value isn't set (or is explicitly
   unset). */
extern const char *env_value(struct env *e);


/*
 * "struct envarray" methods.
 */


/* Get a pointer to the environment variable named NAME.  If no such
   variable exists in ARR one will be created.  The contents of the
   variable will be read from the actual process environment if
   READ_ENV is non-zero.  Fail (return NULL) if READ_ENV is -1 and no
   value is available.

   Warning: the returned value is only valid until the next time that
   envarray_locate_create is called. */

extern struct env *
envarray_locate_create(struct envarray *arr, const char* name, int read_env);

/* Dump all variables in the environment ARR to file F using syntax
   appropriate for the shell SH.  Ignore variables that have been read
   from the environment but not modified. */
extern void envarray_dump(struct envarray *arr, FILE *f, const char *sh);


/* Allocate and create an environment. */
extern struct envarray *create_envarray(void);

/* Destroy and deallocate an environment. */
extern void destroy_envarray(struct envarray *arr);

#endif

==> cmod-1.0.tar.gz: cmod-1.0/env.h <==
/* cmod - set up the user environment with module files.
   Copyright (C) 1997 by the authors of cmod (see AUTHORS).

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA. */

#ifndef ENV_H
#define ENV_H

#include <stdio.h>

/* An environment variable is stored in a "struct env" entry.  All
   codes that need access to the implementation of a "struct env"
   resides in env.c, where the internals of this struct is declared. */

struct env;


/* A collection of environment variables are collectively stored
   in a "struct envarray". */

struct envarray;


/*
 * "struct env" methods.
 */

/* Constructor.  The caller must allocate the memory.  This will turn
   the random bits at e into an env object.  The fragment separator
   will be set to ':'. */

#ifdef PROTOTYPES
extern void env_ctor(struct env *e);
#else
extern void env_ctor();
#endif


/* Destructor.  Frees all memory that is allocated by the object, and
   turns into a pile of random bits.  The memory itself is not
   deallocated. */

#ifdef PROTOTYPES
extern void env_dtor(struct env *e);
#else
extern void env_dtor();
#endif


/* Return true if FRAG is present as a SEP-separated fragment of E. */

#ifdef PROTOTYPES
extern int env_frag_present(struct env *e, char sep, const char *frag);
#else
extern int env_frag_present();
#endif


/* Append a fragment to the variable.  No duplicate check is done.  It
   is the responsibility of the caller to ensure that FRAG doesn't
   contain the fragment delimiter SEP.  Ownership of the memory
   pointed to by FRAG is passed to E. */

#ifdef PROTOTYPES
extern void env_append_one_frag(struct env *e, char sep, const char *frag);
#else
extern void env_append_one_frag();
#endif


/* Split the SEP-separated fragments in FRAGS and append each frag to
   E.  If UNIQUE is true each fragment will only be added if it isn't
   already present.  Ownership of the memory pointed to by FRAGS
   remains with the caller. */

#ifdef PROTOTYPES
extern void env_append_frags(struct env *e, char sep, const char *frags,
			     int unique);
#else
extern void env_append_frags();
#endif


/* Prepend a fragment to the variable.  No duplicate check is done.
   It is the responsibility of the caller to ensure that FRAG doesn't
   contain the fragment delimiter SEP.  Ownership of the memory
   pointed to by FRAG is passed to E. */

#ifdef PROTOTYPES
extern void env_prepend_one_frag(struct env *e, char sep, char *frag);
#else
extern void env_prepend_one_frag();
#endif


/* Split the SEP-separated fragments in FRAGS and prepend each frag to
   E.  If UNIQUE is true any fragment already present in E will be
   removed before the fragment is prepended.  Ownership of the memory
   pointed to by FRAGS remains with the caller.  The first framgent on
   FRAGS will be the first fragment on E after the operation. */

#ifdef PROTOTYPES
extern void env_prepend_frags(struct env *e, char sep, const char *frags,
			      int unique);
#else
extern void env_prepend_frags();
#endif


/* Remove all SEP-separated frags from E which are equal to FRAG. */

#ifdef PROTOTYPES
extern void env_remove_one_frag(struct env *e, char sep, const char *frag);
#else
extern void env_remove_one_frag();
#endif


/* Split the SEP-separated fragments in FRAGS and remove all fragments
   that are equal to any of them from E. */

#ifdef PROTOTYPES
extern void env_remove_frags(struct env *e, char sep, const char *frags);
#else
extern void env_remove_frags();
#endif


/* Set the variable to a non-fragmented string.  Any previous value
   is lost, and the variable becomes non-fragmented.  Ownership of VAL
   passes to E. */

#ifdef PROTOTYPES
extern void env_setenv(struct env *e, char *val);
#else
extern void env_setenv();
#endif

/* Make E explicitly unset. */

#ifdef PROTOTYPES
extern void env_unsetenv(struct env *e);
#else
extern void env_unsetenv();
#endif


/* Dump the value of E to F, readable for shell SH. */

#ifdef PROTOTYPES
extern void env_dump(struct env *e, FILE *f, const char *sh);
#else
extern void env_dump();
#endif


/* Iterate through all fragments.  The iterator can be used like this:

   int i;
   char *fragment;
   for (i = 0; (fragment = env_iterate(e, ':', &i)) != NULL; )
       printf("fragment: %s\n", fragment);

   The loop variable i is incremented each time env_iterate is called.
   env_iterate returns NULL when there are no more fragments to
   fetch. */

#ifdef PROTOTYPES
extern const char *env_iterate(struct env *e, char sep, int *iterator);
#else
extern const char *env_iterate();
#endif


/* Return the value of the variable as a string.  The returned value
   is only valid until the next call to any method that may modify the
   variable.  Returns NULL if the value is explicitly unset.  (If the
   variable isn't set this will return the empty string.) */

#ifdef PROTOTYPES
extern const char *env_value(struct env *e);
#else
extern const char *env_value();
#endif


/*
 * "struct envarray" methods.
 */


/* Get a pointer to the environment variable named NAME.  If no such
   variable exists in ARR one will be created.  The contents of the
   variable will be read from the actual process environment if
   READ_ENV is non-zero.  Fail (return NULL) if READ_ENV is -1 and no
   value is available.

   Warning: the returned value is only valid until the next time that
   envarray_locate_create is called. */

#ifdef PROTOTYPES
extern struct env *
envarray_locate_create(struct envarray *arr, const char* name, int read_env);
#else
extern struct env *envarray_locate_create();
#endif


/* Get a pointer to the environment variable named NAME, or NULL if
   the variable doesn't exist.

   Warning: the returned value is only valid until the next time that
   envarray_locate_create is called.  The value remains valid as long
   as only envarray_locate is called, however.  So, if you want to
   access the values of two variables simultaneously you could do
   something like this:

      struct env *foo, *bar;
      foo = envarray_locate_create(arr, "foo", 1);
      bar = envarray_locate_create(arr, "bar", 1); // foo now points to junk
      foo = envarray_locate(arr, "foo"); // doesn't destroy bar

      // now, both foo and bar are valid
   */

#ifdef PROTOTYPES
extern struct env *envarray_locate(struct envarray* arr, const char* name);
#else
extern struct env *envarray_locate();
#endif


/* Dump all variables in the environment ARR to file F using syntax
   appropriate for the shell SH.  Ignore variables that have been read
   from the environment but not modified. */

#ifdef PROTOTYPES
extern void envarray_dump(struct envarray *arr, FILE *f, const char *sh);
#else
extern void envarray_dump();
#endif


/* Allocate and create an environment. */

#ifdef PROTOTYPES
extern struct envarray *create_envarray(void);
#else
extern struct envarray *create_envarray();
#endif


/* Destroy and deallocate an environment. */

#ifdef PROTOTYPES
extern void destroy_envarray(struct envarray *arr);
#else
extern void destroy_envarray();
#endif

#endif
